@@ -105,7 +105,7 @@ static int vv6450_set_size(struct quickcam *qc, unsigned int width, unsigned int
 {
 	int r = 0;
 	struct qc_sensor_data *sd = &qc->sensor_data;
-	//if (qcdebug&QC_DEBUGLOGIC)
+	if (qcdebug&QC_DEBUGLOGIC)
 	  PDEBUG("vv6450_set_size(quickcam=%p,width=%i,height=%i)",qc,width,height);
 
 	if ( (width <= 162) && (height <= 124) )
@@ -115,17 +115,19 @@ static int vv6450_set_size(struct quickcam *qc, unsigned int width, unsigned int
 		STV_SET_CHECK(0x1505, 0x0f);
 		if(r) goto fail;
 	} else
+#ifndef MIN
+#define MIN(a, b) ((a) < (b) ? (a) : (b))
+#endif
 	if ( (width <= 176) && (height <= 144) )
 	{
 		/* exception for small QCIF even if not good fit */
 		sd->width = 162;
 		sd->height = 124;
-		qc->vwin.width = sd->width;
-		qc->vwin.height = sd->height;
-		PDEBUG("set %dx%d", sd->width, sd->height);
+		qc->vwin.width = MIN(sd->width, width);
+		qc->vwin.height = MIN(sd->height, height);
 		STV_SET_CHECK(0x1505, 0x0f);
 		if(r) goto fail;
-		return 0;
+		//return 0;
 	} else
 	if ( (width <= 162) && (height <= 248) )
 	{
@@ -153,17 +155,16 @@ static int vv6450_set_size(struct quickcam *qc, unsigned int width, unsigned int
 		/* exception for CIF even if not good fit */
 		sd->width = 324;
 		sd->height = 248;
-		qc->vwin.width = sd->width;
-		qc->vwin.height = sd->height;
-		PDEBUG("set %dx%d", sd->width, sd->height);
+		qc->vwin.width = MIN(sd->width, width);
+		qc->vwin.height = MIN(sd->height, height);
 		STV_SET_CHECK(0x1505, 0x02);
 		if(r) goto fail;
-		return 0;
+		//return 0;
 	} else
 #ifdef TRY_HIGHRES
 	if ( (width <= 648) && (height <= 496) )
 	{
-		// this doesn't work
+		// this doesn't work yet
 		sd->width = 648;
 		sd->height = 496;
 		STV_SET_CHECK(0x1505, 0x01);
@@ -171,22 +172,27 @@ static int vv6450_set_size(struct quickcam *qc, unsigned int width, unsigned int
 	} else
 #endif
 	{
+#if 1
 		PDEBUG("Unknown resolution %dx%d, set 324x248", width, height);
 		sd->width = 324;
 		sd->height = 248;
-
 		qc->vwin.width = sd->width;
 		qc->vwin.height = sd->height;
-
-		//r = qc_i2c_wait(qc);
 		STV_SET_CHECK(0x1505, 0x02);
 		if(r) goto fail;
-
+#endif
 		goto fail;
 	}
-	PDEBUG("set %dx%d", sd->width, sd->height);
+#if 0
 	qc->vwin.width = width;
 	qc->vwin.height = height;
+	qc->vwin.width = sd->width;
+	qc->vwin.height = sd->height;
+#endif
+	qc->vwin.width = MIN(sd->width, width);
+	qc->vwin.height = MIN(sd->height, height);
+
+	PDEBUG("set sensor=%dx%d vwin=%dx%d", sd->width, sd->height, qc->vwin.width, qc->vwin.height);
 	return 0;
 fail:	return -1;
 }
@@ -275,8 +281,18 @@ static int vv6450_init(struct quickcam *qc)
 /* LOGTAG */ { NULL, 0x143d, 0x00 },
 
 /* LOGTAG */ { NULL, 0x1442, 0xe2 },
-// 0xe2 at init
-// 0xea at exit... power save?
+// write: 1x1x xxxx
+// read:  1x1x xxxx
+//        bit 5 == button pressed and hold if 0
+// write 0xe2,0xea
+
+// 0x144a
+// 0x00 init
+// bit 7 == button has been pressed, but not handled
+
+// interrupt
+//if(urb->iso_frame_desc[i].status == 0x80) {
+//if(urb->iso_frame_desc[i].status == 0x88) {
 
 /* LOGTAG */ { NULL, 0x1500, 0xd0 },
 /* LOGTAG */ { NULL, 0x1500, 0xd0 },
