@@ -112,6 +112,8 @@ const struct ioctlstruct {
 	{ "retryerrors",	VIDIOCQCGRETRYERRORS,	VIDIOCQCSRETRYERRORS,	FALSE,	flags_bool },
 	{ "compatible", 	VIDIOCQCGCOMPATIBLE,	VIDIOCQCSCOMPATIBLE,	TRUE,	flags_compat },
 	{ "reg",		VIDIOCQCGSTV,		VIDIOCQCSSTV,		FALSE,	NULL },
+	{ "shutteradapt",	VIDIOCQCGSHUTTERADAPT, 	VIDIOCQCSSHUTTERADAPT,	FALSE,	flags_bool },
+	{ "shutterval",		VIDIOCQCGSHUTTERVAL, 	VIDIOCQCSSHUTTERVAL,	FALSE,	NULL },
 	{ "video_nr",		VIDIOCQCGVIDEONR,	VIDIOCQCSVIDEONR,	FALSE,	NULL },
 };
 /* }}} */
@@ -235,6 +237,7 @@ void help(void) {
 "	-o val	Set color strength (increase when setting hue)\n"
 "	-c val	Set contrast (camera gain)\n"
 "	-w val	Set whiteness (image sharpness when quality=best)\n"
+"	-s val	Set shutter time (hardware exposure time)\n"
 "	-g v	Enable gamma correction with the given gamma value\n"
 "	-g rg:gg:bg\n"
 "		Specify different gamma value for each color channel\n"
@@ -559,6 +562,12 @@ int main(int argc, char *argv[])
 					if (r!=0) error("ioctl VIDIOCSPICT");
 					argv += c;
 					break;
+				case 's':	/* Shutter */
+					if (!argp) error("missing shutter value");
+					r = ioctl(fd, VIDIOCQCSSHUTTERVAL, &i);
+					if (r!=0) error("ioctl VIDIOCQCSSHUTTERVAL");
+					argv += c;
+					break;
 				case 'g':
 				case 'e': {
 					struct qc_userlut userlut;
