@@ -111,12 +111,19 @@ struct qc_userlut {
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
 #ifdef USE_KREF
+/* This is just a test */
 #include <linux/kref.h>
 #endif
 #endif
 
+#if defined(CONFIG_INPUT) || defined(CONFIG_INPUT_MODULE)
+#define USE_INPUT
+#include <linux/input.h>
+#endif
+
+
 /* {{{ [fold] SECTION: user configuration */
-#define VERSION		"QuickCam Messenger/Communicate USB $Date: 2004/12/21 10:00:00 $"
+#define VERSION		"QuickCam Messenger/Communicate USB $Date: 2004/12/30 10:00:00 $"
 #ifndef COMPRESS
 #define COMPRESS	0		/* 1=include compression support, 0=otherwise */
 #endif
@@ -145,7 +152,9 @@ struct qc_userlut {
 #define FALSE			0
 #define TRUE			(!FALSE)
 typedef unsigned char Bool;
+#ifndef BIT
 #define BIT(x)		(1<<(x))
+#endif
 #define SIZE(a)		(sizeof(a)/sizeof((a)[0]))
 #define MAX(a,b)	((a)>(b)?(a):(b))
 #define MIN(a,b)	((a)<(b)?(a):(b))
@@ -401,29 +410,6 @@ struct qc_int_data {
 	IDEBUG_VAR
 };
 /* }}} */
-#if 0
-/* {{{ [fold] qc_i2c_data: I2C command queue for writing commands to camera */
-#define I2C_MAXCOMMANDS 	16	/* Should be about 1-2 times the size of transfer buffer (=16) for maximum performance */
-#define I2C_FLAG_WORD 		BIT(0)	/* Set if a 16-bit value is sent, otherwise 8-bit value */
-#define I2C_FLAG_BREAK 		BIT(1)	/* Set if this is the last command in a packet */
-struct qc_i2c_data {
-	struct urb *urb;
-	struct {
-		u8 loval;
-		u8 hival;
-		u8 regnum;
-		u8 flags;
-	} commands[I2C_MAXCOMMANDS];
-	/* 2=URB scheduled, need to schedule extra packet for QuickCam Web at completion */
-	volatile int packets;		/* 0=no URBs scheduled, 1=URB scheduled */
-	volatile unsigned int newhead;	/* Points to first free buffer position */
-	volatile unsigned int head;	/* Points to oldest command which was not yet flushed */
-	volatile unsigned int tail;	/* Points to next position which needs to be send, modified from interrupt */
-	wait_queue_head_t wq;		/* Woken up when all pending data is sent */
-	IDEBUG_VAR
-};
-/* }}} */
-#endif
 /* {{{ [fold] qc_isoc_data: Isochronous transfer queue control data for reading from camera */
 #define ISOC_URBS		2	/* Number of URBs to use */
 #define ISOC_PACKETS		10	/* How many isochronous data packets per URB */
@@ -578,7 +564,13 @@ struct quickcam {
 	struct qc_fmt_data fmt_data;		/* Mostly filled when the device is opened, except for userlut */
 
 	u8 dmabuf[35];				/* Temporary buffer which may be used for DMA transfer */
-
+  
+#ifdef USE_INPUT
+	struct input_dev input;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
+	char input_physname[64];
+#endif
+#endif
 	int button_status;
 	int button_count;
 	int button_pressed;
